Another set of refactoring
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-attr.cc b/helper/ccnb-parser/syntax-tree/attr.cc
similarity index 95%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-attr.cc
rename to helper/ccnb-parser/syntax-tree/attr.cc
index bdc1f0a..fda4c77 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-attr.cc
+++ b/helper/ccnb-parser/syntax-tree/attr.cc
@@ -18,10 +18,11 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-attr.h"
-#include "../ccnb-parser-common.h"
+#include "attr.h"
+#include "../common.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 // length length in octets of UTF-8 encoding of tag name - 1 (minimum tag name length is 1) 
@@ -42,3 +43,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-attr.h b/helper/ccnb-parser/syntax-tree/attr.h
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-attr.h
rename to helper/ccnb-parser/syntax-tree/attr.h
index 1b7d5e8..6238aee 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-attr.h
+++ b/helper/ccnb-parser/syntax-tree/attr.h
@@ -21,10 +21,11 @@
 #ifndef _CCNB_PARSER_ATTR_H_
 #define _CCNB_PARSER_ATTR_H_
 
-#include "ccnb-parser-base-attr.h"
+#include "base-attr.h"
 #include <string>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -56,5 +57,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_ATTR_H_
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-base-attr.h b/helper/ccnb-parser/syntax-tree/base-attr.h
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-base-attr.h
rename to helper/ccnb-parser/syntax-tree/base-attr.h
index 9b20073..d6890a1 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-base-attr.h
+++ b/helper/ccnb-parser/syntax-tree/base-attr.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_BASE_ATTR_H_
 #define _CCNB_PARSER_BASE_ATTR_H_
 
-#include "ccnb-parser-udata.h"
+#include "udata.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -41,5 +42,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_BASE_ATTR_H_
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-base-tag.h b/helper/ccnb-parser/syntax-tree/base-tag.h
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-base-tag.h
rename to helper/ccnb-parser/syntax-tree/base-tag.h
index 15310a5..403dcb4 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-base-tag.h
+++ b/helper/ccnb-parser/syntax-tree/base-tag.h
@@ -21,10 +21,11 @@
 #ifndef _CCNB_PARSER_BASE_TAG_H_
 #define _CCNB_PARSER_BASE_TAG_H_
 
-#include "ccnb-parser-block.h"
+#include "block.h"
 #include <list>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -49,6 +50,7 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_BASE_TAG_H_
 
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-blob.cc b/helper/ccnb-parser/syntax-tree/blob.cc
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-blob.cc
rename to helper/ccnb-parser/syntax-tree/blob.cc
index 159643f..6df6012 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-blob.cc
+++ b/helper/ccnb-parser/syntax-tree/blob.cc
@@ -18,9 +18,10 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-blob.h"
+#include "blob.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 Blob::Blob (Buffer::Iterator &start, uint32_t length)
@@ -47,3 +48,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-blob.h b/helper/ccnb-parser/syntax-tree/blob.h
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-blob.h
rename to helper/ccnb-parser/syntax-tree/blob.h
index 195c84c..1745b1d 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-blob.h
+++ b/helper/ccnb-parser/syntax-tree/blob.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_BLOB_H_
 #define _CCNB_PARSER_BLOB_H_
 
-#include "ccnb-parser-block.h"
+#include "block.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -57,5 +58,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_BLOB_H_
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-block.cc b/helper/ccnb-parser/syntax-tree/block.cc
similarity index 89%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-block.cc
rename to helper/ccnb-parser/syntax-tree/block.cc
index 805582a..0d425dd 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-block.cc
+++ b/helper/ccnb-parser/syntax-tree/block.cc
@@ -18,21 +18,22 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-block.h"
+#include "block.h"
 
-#include "ccnb-parser-blob.h"
-#include "ccnb-parser-udata.h"
-#include "ccnb-parser-tag.h"
-#include "ccnb-parser-dtag.h"
-#include "ccnb-parser-attr.h"
-#include "ccnb-parser-dattr.h"
-#include "ccnb-parser-ext.h"
+#include "blob.h"
+#include "udata.h"
+#include "tag.h"
+#include "dtag.h"
+#include "attr.h"
+#include "dattr.h"
+#include "ext.h"
 
 #include "ns3/log.h"
 
-NS_LOG_COMPONENT_DEFINE ("CcnbParserBlock");
+NS_LOG_COMPONENT_DEFINE ("ndn.CcnbParser.Block");
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /// @cond include_hidden
@@ -95,3 +96,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-block.h b/helper/ccnb-parser/syntax-tree/block.h
similarity index 91%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-block.h
rename to helper/ccnb-parser/syntax-tree/block.h
index 6ea5fba..23604f5 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-block.h
+++ b/helper/ccnb-parser/syntax-tree/block.h
@@ -26,12 +26,13 @@
 #include "ns3/ptr.h"
 
 // visitors
-#include "../visitors/ccnb-parser-void-no-argu-visitor.h"
-#include "../visitors/ccnb-parser-void-visitor.h"
-#include "../visitors/ccnb-parser-no-argu-visitor.h"
-#include "../visitors/ccnb-parser-visitor.h"
+#include "../visitors/void-no-argu-visitor.h"
+#include "../visitors/void-visitor.h"
+#include "../visitors/no-argu-visitor.h"
+#include "../visitors/visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -81,5 +82,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_BLOCK_H_
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-dattr.cc b/helper/ccnb-parser/syntax-tree/dattr.cc
similarity index 96%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-dattr.cc
rename to helper/ccnb-parser/syntax-tree/dattr.cc
index bb6be82..dde424c 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-dattr.cc
+++ b/helper/ccnb-parser/syntax-tree/dattr.cc
@@ -18,9 +18,10 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-dattr.h"
+#include "dattr.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 // dictionary attributes are not used (yet?) in CCNx 
@@ -34,3 +35,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-dattr.h b/helper/ccnb-parser/syntax-tree/dattr.h
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-dattr.h
rename to helper/ccnb-parser/syntax-tree/dattr.h
index 6775017..e4c622c 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-dattr.h
+++ b/helper/ccnb-parser/syntax-tree/dattr.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_DATTR_H_
 #define _CCNB_PARSER_DATTR_H_
 
-#include "ccnb-parser-base-attr.h"
+#include "base-attr.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -55,5 +56,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_DATTR_H_
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-dtag.cc b/helper/ccnb-parser/syntax-tree/dtag.cc
similarity index 96%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-dtag.cc
rename to helper/ccnb-parser/syntax-tree/dtag.cc
index e7d9b98..129b363 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-dtag.cc
+++ b/helper/ccnb-parser/syntax-tree/dtag.cc
@@ -18,12 +18,13 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-dtag.h"
+#include "dtag.h"
 
-#include "ccnb-parser-base-attr.h"
-#include "ccnb-parser-base-tag.h"
+#include "base-attr.h"
+#include "base-tag.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 Dtag::Dtag (Buffer::Iterator &start, uint32_t dtag)
@@ -85,3 +86,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-dtag.h b/helper/ccnb-parser/syntax-tree/dtag.h
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-dtag.h
rename to helper/ccnb-parser/syntax-tree/dtag.h
index cca0bba..cf9871e 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-dtag.h
+++ b/helper/ccnb-parser/syntax-tree/dtag.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_DTAG_H_
 #define _CCNB_PARSER_DTAG_H_
 
-#include "ccnb-parser-base-tag.h"
+#include "base-tag.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -60,5 +61,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_DTAG_H_
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-ext.cc b/helper/ccnb-parser/syntax-tree/ext.cc
similarity index 96%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-ext.cc
rename to helper/ccnb-parser/syntax-tree/ext.cc
index 7d90019..b80743c 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-ext.cc
+++ b/helper/ccnb-parser/syntax-tree/ext.cc
@@ -18,9 +18,10 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-ext.h"
+#include "ext.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 Ext::Ext (Buffer::Iterator &start, uint32_t extSubtype)
@@ -30,3 +31,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-ext.h b/helper/ccnb-parser/syntax-tree/ext.h
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-ext.h
rename to helper/ccnb-parser/syntax-tree/ext.h
index 568706b..072405c 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-ext.h
+++ b/helper/ccnb-parser/syntax-tree/ext.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_EXT_H_
 #define _CCNB_PARSER_EXT_H_
 
-#include "ccnb-parser-block.h"
+#include "block.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -55,5 +56,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_EXT_H_
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-tag.cc b/helper/ccnb-parser/syntax-tree/tag.cc
similarity index 96%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-tag.cc
rename to helper/ccnb-parser/syntax-tree/tag.cc
index 723c57e..5a0d96c 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-tag.cc
+++ b/helper/ccnb-parser/syntax-tree/tag.cc
@@ -18,11 +18,12 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-tag.h"
+#include "tag.h"
 
-#include "ccnb-parser-base-attr.h"
+#include "base-attr.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 Tag::Tag (Buffer::Iterator &start, uint32_t length)
@@ -64,3 +65,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-tag.h b/helper/ccnb-parser/syntax-tree/tag.h
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-tag.h
rename to helper/ccnb-parser/syntax-tree/tag.h
index c80581d..94f4d32 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-tag.h
+++ b/helper/ccnb-parser/syntax-tree/tag.h
@@ -21,10 +21,11 @@
 #ifndef _CCNB_PARSER_TAG_H_
 #define _CCNB_PARSER_TAG_H_
 
-#include "ccnb-parser-base-tag.h"
+#include "base-tag.h"
 #include <string>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -56,5 +57,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_TAG_H_
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-udata.cc b/helper/ccnb-parser/syntax-tree/udata.cc
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-udata.cc
rename to helper/ccnb-parser/syntax-tree/udata.cc
index 91cba15..cd69aba 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-udata.cc
+++ b/helper/ccnb-parser/syntax-tree/udata.cc
@@ -18,9 +18,10 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-udata.h"
+#include "udata.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 Udata::Udata (Buffer::Iterator &start, uint32_t length)
@@ -44,3 +45,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/syntax-tree/ccnb-parser-udata.h b/helper/ccnb-parser/syntax-tree/udata.h
similarity index 97%
rename from helper/ccnb-parser/syntax-tree/ccnb-parser-udata.h
rename to helper/ccnb-parser/syntax-tree/udata.h
index b6ef2c2..b589ea4 100644
--- a/helper/ccnb-parser/syntax-tree/ccnb-parser-udata.h
+++ b/helper/ccnb-parser/syntax-tree/udata.h
@@ -21,10 +21,11 @@
 #ifndef _CCNB_PARSER_UDATA_H_
 #define _CCNB_PARSER_UDATA_H_
 
-#include "ccnb-parser-block.h"
+#include "block.h"
 #include <string>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -54,5 +55,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_UDATA_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-content-type-visitor.cc b/helper/ccnb-parser/visitors/content-type-visitor.cc
similarity index 93%
rename from helper/ccnb-parser/visitors/ccnb-parser-content-type-visitor.cc
rename to helper/ccnb-parser/visitors/content-type-visitor.cc
index 34608b1..a89b99c 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-content-type-visitor.cc
+++ b/helper/ccnb-parser/visitors/content-type-visitor.cc
@@ -18,10 +18,11 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-content-type-visitor.h"
-#include "../syntax-tree/ccnb-parser-blob.h"
+#include "content-type-visitor.h"
+#include "../syntax-tree/blob.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 boost::any
@@ -48,3 +49,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-content-type-visitor.h b/helper/ccnb-parser/visitors/content-type-visitor.h
similarity index 96%
rename from helper/ccnb-parser/visitors/ccnb-parser-content-type-visitor.h
rename to helper/ccnb-parser/visitors/content-type-visitor.h
index 0c3cc6c..2cbd883 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-content-type-visitor.h
+++ b/helper/ccnb-parser/visitors/content-type-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_CONTENT_TYPE_VISITOR_H_
 #define _CCNB_PARSER_CONTENT_TYPE_VISITOR_H_
 
-#include "ccnb-parser-no-argu-depth-first-visitor.h"
+#include "no-argu-depth-first-visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -44,5 +45,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_CONTENT_TYPE_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-depth-first-visitor.cc b/helper/ccnb-parser/visitors/depth-first-visitor.cc
similarity index 86%
rename from helper/ccnb-parser/visitors/ccnb-parser-depth-first-visitor.cc
rename to helper/ccnb-parser/visitors/depth-first-visitor.cc
index 9a89c19..305fff6 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-depth-first-visitor.cc
+++ b/helper/ccnb-parser/visitors/depth-first-visitor.cc
@@ -18,19 +18,20 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-depth-first-visitor.h"
+#include "depth-first-visitor.h"
 
-#include "../syntax-tree/ccnb-parser-blob.h"
-#include "../syntax-tree/ccnb-parser-udata.h"
-#include "../syntax-tree/ccnb-parser-tag.h"
-#include "../syntax-tree/ccnb-parser-dtag.h"
-#include "../syntax-tree/ccnb-parser-attr.h"
-#include "../syntax-tree/ccnb-parser-dattr.h"
-#include "../syntax-tree/ccnb-parser-ext.h"
+#include "../syntax-tree/blob.h"
+#include "../syntax-tree/udata.h"
+#include "../syntax-tree/tag.h"
+#include "../syntax-tree/dtag.h"
+#include "../syntax-tree/attr.h"
+#include "../syntax-tree/dattr.h"
+#include "../syntax-tree/ext.h"
 
 #include <boost/foreach.hpp>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 boost::any
@@ -106,3 +107,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-depth-first-visitor.h b/helper/ccnb-parser/visitors/depth-first-visitor.h
similarity index 97%
rename from helper/ccnb-parser/visitors/ccnb-parser-depth-first-visitor.h
rename to helper/ccnb-parser/visitors/depth-first-visitor.h
index 98c3c96..2257802 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-depth-first-visitor.h
+++ b/helper/ccnb-parser/visitors/depth-first-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_DEPTH_FIRST_VISITOR_H_
 #define _CCNB_PARSER_DEPTH_FIRST_VISITOR_H_
 
-#include "ccnb-parser-visitor.h"
+#include "visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -44,5 +45,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_DEPTH_FIRST_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-interest-visitor.cc b/helper/ccnb-parser/visitors/interest-visitor.cc
similarity index 90%
rename from helper/ccnb-parser/visitors/ccnb-parser-interest-visitor.cc
rename to helper/ccnb-parser/visitors/interest-visitor.cc
index 5188f8d..175eaad 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-interest-visitor.cc
+++ b/helper/ccnb-parser/visitors/interest-visitor.cc
@@ -18,34 +18,35 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-interest-visitor.h"
+#include "interest-visitor.h"
 
-#include "../syntax-tree/ccnb-parser-block.h"
-#include "../syntax-tree/ccnb-parser-dtag.h"
+#include "../syntax-tree/block.h"
+#include "../syntax-tree/dtag.h"
 
 #include "ns3/ndn-name-components.h"
+#include "ns3/ndn-interest-header.h"
 
 #include "ns3/assert.h"
 #include "ns3/nstime.h"
 
-#include "ns3/ndn-interest-header.h"
-#include "ccnb-parser-name-components-visitor.h"
-#include "ccnb-parser-non-negative-integer-visitor.h"
-#include "ccnb-parser-timestamp-visitor.h"
-#include "ccnb-parser-uint32t-blob-visitor.h"
+#include "name-components-visitor.h"
+#include "non-negative-integer-visitor.h"
+#include "timestamp-visitor.h"
+#include "uint32t-blob-visitor.h"
 
 #include <boost/foreach.hpp>
 
 #include "ns3/log.h"
 
-NS_LOG_COMPONENT_DEFINE ("CcnbParserInterestVisitor");
+NS_LOG_COMPONENT_DEFINE ("ndn.CcnbParser.InterestVisitor");
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 // We don't care about any other fields
 void
-InterestVisitor::visit (Dtag &n, boost::any param/*should be NdnInterestHeader* */)
+InterestVisitor::visit (Dtag &n, boost::any param/*should be InterestHeader* */)
 {
   // uint32_t n.m_dtag;
   // std::list<Ptr<Block> > n.m_nestedBlocks;
@@ -55,7 +56,7 @@
   static TimestampVisitor          timestampVisitor;
   static Uint32tBlobVisitor        nonceVisitor;
   
-  NdnInterestHeader &interest = *(boost::any_cast<NdnInterestHeader*> (param));
+  InterestHeader &interest = *(boost::any_cast<InterestHeader*> (param));
 
   switch (n.m_dtag)
     {
@@ -73,7 +74,7 @@
         NS_LOG_DEBUG ("Name");
 
         // process name components
-        Ptr<NdnNameComponents> name = Create<NdnNameComponents> ();
+        Ptr<NameComponents> name = Create<NameComponents> ();
         
         BOOST_FOREACH (Ptr<Block> block, n.m_nestedTags)
           {
@@ -106,7 +107,7 @@
       {
         NS_LOG_DEBUG ("Exclude");
         // process exclude components
-        Ptr<NdnNameComponents> exclude = Create<NdnNameComponents> ();
+        Ptr<NameComponents> exclude = Create<NameComponents> ();
         
         BOOST_FOREACH (Ptr<Block> block, n.m_nestedTags)
           {
@@ -183,4 +184,5 @@
 }
 
 } // namespace CcnbParser
+} // namespace ndn
 } // namespace ns3
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-interest-visitor.h b/helper/ccnb-parser/visitors/interest-visitor.h
similarity index 92%
rename from helper/ccnb-parser/visitors/ccnb-parser-interest-visitor.h
rename to helper/ccnb-parser/visitors/interest-visitor.h
index 35a1e13..f78d07f 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-interest-visitor.h
+++ b/helper/ccnb-parser/visitors/interest-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_INTEREST_VISITOR_H_
 #define _CCNB_PARSER_INTEREST_VISITOR_H_
 
-#include "ccnb-parser-void-depth-first-visitor.h"
+#include "void-depth-first-visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -44,7 +45,8 @@
   virtual void visit (Dtag &n, boost::any param/*should be CcnxInterestHeader* */);
 };
 
-}
-}
+} // namespace CcnbParser
+} // namespace ndn
+} // namespace ns3
 
 #endif // _CCNB_PARSER_INTEREST_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-name-components-visitor.cc b/helper/ccnb-parser/visitors/name-components-visitor.cc
similarity index 87%
rename from helper/ccnb-parser/visitors/ccnb-parser-name-components-visitor.cc
rename to helper/ccnb-parser/visitors/name-components-visitor.cc
index 387292b..ef87281 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-name-components-visitor.cc
+++ b/helper/ccnb-parser/visitors/name-components-visitor.cc
@@ -18,23 +18,25 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-name-components-visitor.h"
+#include "name-components-visitor.h"
 
-#include "ccnb-parser-string-visitor.h"
-#include "../syntax-tree/ccnb-parser-dtag.h"
+#include "string-visitor.h"
+#include "../syntax-tree/dtag.h"
+
 #include "ns3/ndn-name-components.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 void
-NameComponentsVisitor::visit (Dtag &n, boost::any param/*should be NdnNameComponents* */)
+NameComponentsVisitor::visit (Dtag &n, boost::any param/*should be NameComponents* */)
 {
   // uint32_t n.m_dtag;
   // std::list<Ptr<Block> > n.m_nestedBlocks;
   static StringVisitor stringVisitor; 
  
-  NdnNameComponents &components = *(boost::any_cast<NdnNameComponents*> (param));
+  NameComponents &components = *(boost::any_cast<NameComponents*> (param));
 
   switch (n.m_dtag)
     {
@@ -55,3 +57,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-name-components-visitor.h b/helper/ccnb-parser/visitors/name-components-visitor.h
similarity index 95%
rename from helper/ccnb-parser/visitors/ccnb-parser-name-components-visitor.h
rename to helper/ccnb-parser/visitors/name-components-visitor.h
index 70257c5..823de35 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-name-components-visitor.h
+++ b/helper/ccnb-parser/visitors/name-components-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_NAME_COMPONENTS_VISITOR_H_
 #define _CCNB_PARSER_NAME_COMPONENTS_VISITOR_H_
 
-#include "ccnb-parser-void-depth-first-visitor.h"
+#include "void-depth-first-visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -38,6 +39,7 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_NAME_COMPONENTS_VISITOR_H_
 
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-no-argu-depth-first-visitor.cc b/helper/ccnb-parser/visitors/no-argu-depth-first-visitor.cc
similarity index 85%
rename from helper/ccnb-parser/visitors/ccnb-parser-no-argu-depth-first-visitor.cc
rename to helper/ccnb-parser/visitors/no-argu-depth-first-visitor.cc
index 12264fd..53f1122 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-no-argu-depth-first-visitor.cc
+++ b/helper/ccnb-parser/visitors/no-argu-depth-first-visitor.cc
@@ -18,19 +18,20 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-no-argu-depth-first-visitor.h"
+#include "no-argu-depth-first-visitor.h"
 
-#include "../syntax-tree/ccnb-parser-blob.h"
-#include "../syntax-tree/ccnb-parser-udata.h"
-#include "../syntax-tree/ccnb-parser-tag.h"
-#include "../syntax-tree/ccnb-parser-dtag.h"
-#include "../syntax-tree/ccnb-parser-attr.h"
-#include "../syntax-tree/ccnb-parser-dattr.h"
-#include "../syntax-tree/ccnb-parser-ext.h"
+#include "../syntax-tree/blob.h"
+#include "../syntax-tree/udata.h"
+#include "../syntax-tree/tag.h"
+#include "../syntax-tree/dtag.h"
+#include "../syntax-tree/attr.h"
+#include "../syntax-tree/dattr.h"
+#include "../syntax-tree/ext.h"
 
 #include <boost/foreach.hpp>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 boost::any
@@ -106,3 +107,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-no-argu-depth-first-visitor.h b/helper/ccnb-parser/visitors/no-argu-depth-first-visitor.h
similarity index 96%
rename from helper/ccnb-parser/visitors/ccnb-parser-no-argu-depth-first-visitor.h
rename to helper/ccnb-parser/visitors/no-argu-depth-first-visitor.h
index 7d3841d..4b6c2e9 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-no-argu-depth-first-visitor.h
+++ b/helper/ccnb-parser/visitors/no-argu-depth-first-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_NO_ARGU_DEPTH_FIRST_VISITOR_H_
 #define _CCNB_PARSER_NO_ARGU_DEPTH_FIRST_VISITOR_H_
 
-#include "ccnb-parser-no-argu-visitor.h"
+#include "no-argu-visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -44,5 +45,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_NO_ARGU_DEPTH_FIRST_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-no-argu-visitor.h b/helper/ccnb-parser/visitors/no-argu-visitor.h
similarity index 97%
rename from helper/ccnb-parser/visitors/ccnb-parser-no-argu-visitor.h
rename to helper/ccnb-parser/visitors/no-argu-visitor.h
index 95be166..abbf843 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-no-argu-visitor.h
+++ b/helper/ccnb-parser/visitors/no-argu-visitor.h
@@ -21,10 +21,11 @@
 #ifndef _CCNB_PARSER_NO_ARGU_VISITOR_H_
 #define _CCNB_PARSER_NO_ARGU_VISITOR_H_
 
-#include "../ccnb-parser-common.h"
+#include "../common.h"
 #include <boost/any.hpp>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -50,5 +51,6 @@
   
 }
 }
+}
 
 #endif // _CCNB_PARSER_NO_ARGU_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-non-negative-integer-visitor.cc b/helper/ccnb-parser/visitors/non-negative-integer-visitor.cc
similarity index 90%
rename from helper/ccnb-parser/visitors/ccnb-parser-non-negative-integer-visitor.cc
rename to helper/ccnb-parser/visitors/non-negative-integer-visitor.cc
index a9aed41..d5fc041 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-non-negative-integer-visitor.cc
+++ b/helper/ccnb-parser/visitors/non-negative-integer-visitor.cc
@@ -18,13 +18,14 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-non-negative-integer-visitor.h"
+#include "non-negative-integer-visitor.h"
 
-#include "../syntax-tree/ccnb-parser-blob.h"
-#include "../syntax-tree/ccnb-parser-udata.h"
+#include "../syntax-tree/blob.h"
+#include "../syntax-tree/udata.h"
 #include <sstream>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 boost::any
@@ -49,3 +50,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-non-negative-integer-visitor.h b/helper/ccnb-parser/visitors/non-negative-integer-visitor.h
similarity index 95%
rename from helper/ccnb-parser/visitors/ccnb-parser-non-negative-integer-visitor.h
rename to helper/ccnb-parser/visitors/non-negative-integer-visitor.h
index 7ecc3a9..2bb9f91 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-non-negative-integer-visitor.h
+++ b/helper/ccnb-parser/visitors/non-negative-integer-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_NON_NEGATIVE_INTEGER_VISITOR_H_
 #define _CCNB_PARSER_NON_NEGATIVE_INTEGER_VISITOR_H_
 
-#include "ccnb-parser-no-argu-depth-first-visitor.h"
+#include "no-argu-depth-first-visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -41,5 +42,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_NON_NEGATIVE_INTEGER_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-string-visitor.cc b/helper/ccnb-parser/visitors/string-visitor.cc
similarity index 89%
rename from helper/ccnb-parser/visitors/ccnb-parser-string-visitor.cc
rename to helper/ccnb-parser/visitors/string-visitor.cc
index 6fb5e6b..5f44bf3 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-string-visitor.cc
+++ b/helper/ccnb-parser/visitors/string-visitor.cc
@@ -18,11 +18,12 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-string-visitor.h"
-#include "../syntax-tree/ccnb-parser-udata.h"
-#include "../syntax-tree/ccnb-parser-blob.h"
+#include "string-visitor.h"
+#include "../syntax-tree/udata.h"
+#include "../syntax-tree/blob.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 boost::any
@@ -41,3 +42,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-string-visitor.h b/helper/ccnb-parser/visitors/string-visitor.h
similarity index 95%
rename from helper/ccnb-parser/visitors/ccnb-parser-string-visitor.h
rename to helper/ccnb-parser/visitors/string-visitor.h
index 2a1e8ed..ea285d1 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-string-visitor.h
+++ b/helper/ccnb-parser/visitors/string-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_STRING_VISITOR_H_
 #define _CCNB_PARSER_STRING_VISITOR_H_
 
-#include "ccnb-parser-no-argu-depth-first-visitor.h"
+#include "no-argu-depth-first-visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -41,5 +42,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_STRING_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-timestamp-visitor.cc b/helper/ccnb-parser/visitors/timestamp-visitor.cc
similarity index 95%
rename from helper/ccnb-parser/visitors/ccnb-parser-timestamp-visitor.cc
rename to helper/ccnb-parser/visitors/timestamp-visitor.cc
index 4569bb9..5917711 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-timestamp-visitor.cc
+++ b/helper/ccnb-parser/visitors/timestamp-visitor.cc
@@ -18,12 +18,13 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-timestamp-visitor.h"
-#include "../syntax-tree/ccnb-parser-blob.h"
+#include "timestamp-visitor.h"
+#include "../syntax-tree/blob.h"
 
 #include "ns3/nstime.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 boost::any/*Time*/
@@ -61,3 +62,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-timestamp-visitor.h b/helper/ccnb-parser/visitors/timestamp-visitor.h
similarity index 95%
rename from helper/ccnb-parser/visitors/ccnb-parser-timestamp-visitor.h
rename to helper/ccnb-parser/visitors/timestamp-visitor.h
index ff7e8c8..3884ff6 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-timestamp-visitor.h
+++ b/helper/ccnb-parser/visitors/timestamp-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_TIMESTAMP_VISITOR_H_
 #define _CCNB_PARSER_TIMESTAMP_VISITOR_H_
 
-#include "ccnb-parser-no-argu-depth-first-visitor.h"
+#include "no-argu-depth-first-visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -41,5 +42,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_TIMESTAMP_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-uint32t-blob-visitor.cc b/helper/ccnb-parser/visitors/uint32t-blob-visitor.cc
similarity index 92%
rename from helper/ccnb-parser/visitors/ccnb-parser-uint32t-blob-visitor.cc
rename to helper/ccnb-parser/visitors/uint32t-blob-visitor.cc
index fbeee6e..351cc36 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-uint32t-blob-visitor.cc
+++ b/helper/ccnb-parser/visitors/uint32t-blob-visitor.cc
@@ -18,10 +18,11 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-uint32t-blob-visitor.h"
-#include "../syntax-tree/ccnb-parser-blob.h"
+#include "uint32t-blob-visitor.h"
+#include "../syntax-tree/blob.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 boost::any
@@ -43,3 +44,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-uint32t-blob-visitor.h b/helper/ccnb-parser/visitors/uint32t-blob-visitor.h
similarity index 96%
rename from helper/ccnb-parser/visitors/ccnb-parser-uint32t-blob-visitor.h
rename to helper/ccnb-parser/visitors/uint32t-blob-visitor.h
index e06273f..de5f374 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-uint32t-blob-visitor.h
+++ b/helper/ccnb-parser/visitors/uint32t-blob-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_UINT32T_BLOB_VISITOR_H_
 #define _CCNB_PARSER_UINT32T_BLOB_VISITOR_H_
 
-#include "ccnb-parser-no-argu-depth-first-visitor.h"
+#include "no-argu-depth-first-visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -44,5 +45,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_UINT32T_BLOB_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-visitor.h b/helper/ccnb-parser/visitors/visitor.h
similarity index 95%
rename from helper/ccnb-parser/visitors/ccnb-parser-visitor.h
rename to helper/ccnb-parser/visitors/visitor.h
index bc858eb..76744ee 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-visitor.h
+++ b/helper/ccnb-parser/visitors/visitor.h
@@ -21,10 +21,11 @@
 #ifndef _CCNB_PARSER_VISITOR_H_
 #define _CCNB_PARSER_VISITOR_H_
 
-#include "../ccnb-parser-common.h"
+#include "../common.h"
 #include <boost/any.hpp>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -48,7 +49,8 @@
   virtual ~Visitor () { }
 };                                                
                                                   
-}                                                 
+}
+}
 }                                                 
                                                   
 #endif // _CCNB_PARSER_VISITOR_H_                             
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-void-depth-first-visitor.cc b/helper/ccnb-parser/visitors/void-depth-first-visitor.cc
similarity index 85%
rename from helper/ccnb-parser/visitors/ccnb-parser-void-depth-first-visitor.cc
rename to helper/ccnb-parser/visitors/void-depth-first-visitor.cc
index 05218b5..1a1770a 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-void-depth-first-visitor.cc
+++ b/helper/ccnb-parser/visitors/void-depth-first-visitor.cc
@@ -18,19 +18,20 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-void-depth-first-visitor.h"
+#include "void-depth-first-visitor.h"
 
-#include "../syntax-tree/ccnb-parser-blob.h"
-#include "../syntax-tree/ccnb-parser-udata.h"
-#include "../syntax-tree/ccnb-parser-tag.h"
-#include "../syntax-tree/ccnb-parser-dtag.h"
-#include "../syntax-tree/ccnb-parser-attr.h"
-#include "../syntax-tree/ccnb-parser-dattr.h"
-#include "../syntax-tree/ccnb-parser-ext.h"
+#include "../syntax-tree/blob.h"
+#include "../syntax-tree/udata.h"
+#include "../syntax-tree/tag.h"
+#include "../syntax-tree/dtag.h"
+#include "../syntax-tree/attr.h"
+#include "../syntax-tree/dattr.h"
+#include "../syntax-tree/ext.h"
 
 #include <boost/foreach.hpp>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 void
@@ -99,3 +100,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-void-depth-first-visitor.h b/helper/ccnb-parser/visitors/void-depth-first-visitor.h
similarity index 97%
rename from helper/ccnb-parser/visitors/ccnb-parser-void-depth-first-visitor.h
rename to helper/ccnb-parser/visitors/void-depth-first-visitor.h
index 35283d2..2e1862e 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-void-depth-first-visitor.h
+++ b/helper/ccnb-parser/visitors/void-depth-first-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_VOID_DEPTH_FIRST_VISITOR_H_
 #define _CCNB_PARSER_VOID_DEPTH_FIRST_VISITOR_H_
 
-#include "ccnb-parser-void-visitor.h"
+#include "void-visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -44,5 +45,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_VOID_DEPTH_FIRST_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-void-no-argu-depth-first-visitor.cc b/helper/ccnb-parser/visitors/void-no-argu-depth-first-visitor.cc
similarity index 84%
rename from helper/ccnb-parser/visitors/ccnb-parser-void-no-argu-depth-first-visitor.cc
rename to helper/ccnb-parser/visitors/void-no-argu-depth-first-visitor.cc
index 15519f2..439bf93 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-void-no-argu-depth-first-visitor.cc
+++ b/helper/ccnb-parser/visitors/void-no-argu-depth-first-visitor.cc
@@ -18,19 +18,20 @@
  * Author: Alexander Afanasyev <alexander.afanasyev@ucla.edu>
  */
 
-#include "ccnb-parser-void-no-argu-depth-first-visitor.h"
+#include "void-no-argu-depth-first-visitor.h"
 
-#include "../syntax-tree/ccnb-parser-blob.h"
-#include "../syntax-tree/ccnb-parser-udata.h"
-#include "../syntax-tree/ccnb-parser-tag.h"
-#include "../syntax-tree/ccnb-parser-dtag.h"
-#include "../syntax-tree/ccnb-parser-attr.h"
-#include "../syntax-tree/ccnb-parser-dattr.h"
-#include "../syntax-tree/ccnb-parser-ext.h"
+#include "../syntax-tree/blob.h"
+#include "../syntax-tree/udata.h"
+#include "../syntax-tree/tag.h"
+#include "../syntax-tree/dtag.h"
+#include "../syntax-tree/attr.h"
+#include "../syntax-tree/dattr.h"
+#include "../syntax-tree/ext.h"
 
 #include <boost/foreach.hpp>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 void
@@ -99,3 +100,4 @@
 
 }
 }
+}
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-void-no-argu-depth-first-visitor.h b/helper/ccnb-parser/visitors/void-no-argu-depth-first-visitor.h
similarity index 96%
rename from helper/ccnb-parser/visitors/ccnb-parser-void-no-argu-depth-first-visitor.h
rename to helper/ccnb-parser/visitors/void-no-argu-depth-first-visitor.h
index e796c7f..995f90a 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-void-no-argu-depth-first-visitor.h
+++ b/helper/ccnb-parser/visitors/void-no-argu-depth-first-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_VOID_NO_ARGU_DEPTH_FIRST_VISITOR_H_
 #define _CCNB_PARSER_VOID_NO_ARGU_DEPTH_FIRST_VISITOR_H_
 
-#include "ccnb-parser-void-no-argu-visitor.h"
+#include "void-no-argu-visitor.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -44,5 +45,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_VOID_NO_ARGU_DEPTH_FIRST_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-void-no-argu-visitor.h b/helper/ccnb-parser/visitors/void-no-argu-visitor.h
similarity index 97%
rename from helper/ccnb-parser/visitors/ccnb-parser-void-no-argu-visitor.h
rename to helper/ccnb-parser/visitors/void-no-argu-visitor.h
index 25f9e50..6dccf4e 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-void-no-argu-visitor.h
+++ b/helper/ccnb-parser/visitors/void-no-argu-visitor.h
@@ -21,9 +21,10 @@
 #ifndef _CCNB_PARSER_VOID_NO_ARGU_VISITOR_H_
 #define _CCNB_PARSER_VOID_NO_ARGU_VISITOR_H_
 
-#include "../ccnb-parser-common.h"
+#include "../common.h"
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -49,5 +50,6 @@
   
 }
 }
+}
 
 #endif // _CCNB_PARSER_VOID_NO_ARGU_VISITOR_H_
diff --git a/helper/ccnb-parser/visitors/ccnb-parser-void-visitor.h b/helper/ccnb-parser/visitors/void-visitor.h
similarity index 97%
rename from helper/ccnb-parser/visitors/ccnb-parser-void-visitor.h
rename to helper/ccnb-parser/visitors/void-visitor.h
index 1f9d1fa..6ad7eed 100644
--- a/helper/ccnb-parser/visitors/ccnb-parser-void-visitor.h
+++ b/helper/ccnb-parser/visitors/void-visitor.h
@@ -21,10 +21,11 @@
 #ifndef _CCNB_PARSER_VOID_VISITOR_H_
 #define _CCNB_PARSER_VOID_VISITOR_H_
 
-#include "../ccnb-parser-common.h"
+#include "../common.h"
 #include <boost/any.hpp>
 
 namespace ns3 {
+namespace ndn {
 namespace CcnbParser {
 
 /**
@@ -50,5 +51,6 @@
 
 }
 }
+}
 
 #endif // _CCNB_PARSER_VOID_VISITOR_H_
diff --git a/helper/ccnb-parser/ccnb-parser-common.h b/helper/ccnb-parser/common.h
similarity index 97%
rename from helper/ccnb-parser/ccnb-parser-common.h
rename to helper/ccnb-parser/common.h
index 528bcb0..260ae74 100644
--- a/helper/ccnb-parser/ccnb-parser-common.h
+++ b/helper/ccnb-parser/common.h
@@ -22,13 +22,14 @@
 #define _CCNB_PARSER_COMMON_H_
 
 namespace ns3 {
+namespace ndn {
 
 /**
  * \ingroup ccnx
  * \defgroup ccnx-ccnb CCNB decoding routines
  */
 /**
- * \ingroup ccnx-ccnb
+ * \ingroup ndn-ccnb
  * \brief Namespace for ccnb parer
  */
 namespace CcnbParser {
@@ -174,6 +175,7 @@
 };
 
 } // namespace CcnxParser
+} // namespace ndn
 } // namespace ns3
 
 #endif // _CCNB_PARSER_COMMON_H_
@@ -22,13 +22,14 @@
 
 /**
- * \ingroup ccnx
- * \defgroup ccnx-ccnb CCNB decoding routines
+ * \ingroup ndn
+ * \defgroup ndn-ccnb CCNB decoding routines
  */
 /**